@@ -11,6 +11,8 @@ from qds_ops.entities.oozie_slave import OozieSlave
 from qds_ops.entities.oozie import Oozie
 from qds_ops.entities.chef import Chef
 from qds_ops.entities.rds import RDS
+from qds_ops.entities.scheduler import Scheduler
+from qds_ops.entities.default_dj import DefaultDJ
 from qds_ops.utils import argparse
 from qds_ops import __version__
 from inflection import camelize
@@ -30,6 +32,8 @@ def main():
     slave = OozieSlave(subparsers)
     oozie = Oozie(subparsers)
     rds = RDS(subparsers)
+    scheduler = Scheduler(subparsers)
+    defaultDJ = DefaultDJ(subparsers)
 
     args = argparser.parse_args()
     args.func(args)
